# -*- coding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2010 Nexedi SA and Contributors. All Rights Reserved.
# Copyright (c) 2006-2008 Zope Corporation and Contributors.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

import os
import logging
import shutil

import zc.buildout

class Recipe(object):
    
    def __init__(self, buildout, name, options):
        self.buildout, self.options, self.name = buildout, options, name
        self.logger=logging.getLogger(self.name)

        options.setdefault('executable',
            self.buildout['buildout']['executable'])

        options['location'] = os.path.join(
            buildout['buildout']['parts-directory'],
            self.name,
            )


    def install(self):
        options = self.options
        location = options['location']

        if os.path.exists(location):
            shutil.rmtree(location)
        os.mkdir(location)

        base = options['bt5_base']
        os.chdir(base)
        for url in options.get('bt5_urls', '').splitlines():
            if not url:
                continue
            url_base, bt5 = url.split()
            if bt5[-1] == '/':
                bt5 = bt5[:-1]
            self.logger.info("Creating bt5 %s" % bt5)
            # TODO: use python tarfile module
            assert os.spawnlp(
                      os.P_WAIT, 'tar', 'tar',
                      '--exclude=.svn', '-czf',
                      os.path.join(location, '%s.bt5' % bt5), bt5) == 0

        os.chdir(location)
        self.logger.info("Generating bt5list")
        assert os.spawnl(
                  os.P_WAIT, os.path.normpath(options['executable']),
                  zc.buildout.easy_install._safe_arg(options['executable']),
                  zc.buildout.easy_install._safe_arg(options['genbt5list']),
                ) == 0
        
        return location

    update = install

